@@ -1,4 +1,4 @@
-# Copyright 2016-2021 The Van Valen Lab at the California Institute of
+# Copyright 2016-2022 The Van Valen Lab at the California Institute of
 # Technology (Caltech), with support from the Paul Allen Family Foundation,
 # Google, & National Institutes of Health (NIH) under Grant U24CA224309-01.
 # All rights reserved.
@@ -33,7 +33,7 @@ from tensorflow.python.platform import test
 import numpy as np
 import skimage as sk
 
-from deepcell.model_zoo.featurenet import siamese_model
+from deepcell.model_zoo.tracking import GNNTrackingModel
 from deepcell.applications import CellTracking
 
 
@@ -66,17 +66,12 @@ class TestCellTracking(test.TestCase):
 
     def test_cell_tracking_app(self):
         with self.cached_session():
-            input_shape = (32, 32, 1)
-            neighborhood_scale_size = 30
-            features = {'appearance', 'distance', 'neighborhood', 'regionprop'}
+            # Instantiate model
+            tm = GNNTrackingModel()
 
-            model = siamese_model(
-                input_shape=input_shape,
-                neighborhood_scale_size=neighborhood_scale_size,
-                features=features)
-
-            # test instantiation
-            app = CellTracking(model=model)
+            # Test instantiation
+            app = CellTracking(model=tm.inference_model,
+                               neighborhood_encoder=tm.neighborhood_encoder)
 
             # test output shape
             shape = app.model.output_shape
