@@ -1,4 +1,4 @@
-# Copyright 2016-2021 The Van Valen Lab at the California Institute of
+# Copyright 2016-2022 The Van Valen Lab at the California Institute of
 # Technology (Caltech), with support from the Paul Allen Family Foundation,
 # Google, & National Institutes of Health (NIH) under Grant U24CA224309-01.
 # All rights reserved.
@@ -40,7 +40,7 @@ import tqdm
 import tensorflow as tf
 import tensorflow_addons as tfa
 
-from deepcell_tracking.utils import load_trks
+from deepcell_tracking.trk_io import load_trks
 from deepcell_tracking.utils import get_max_cells
 from deepcell_tracking.utils import get_image_features
 from deepcell_tracking.utils import is_valid_lineage
@@ -53,7 +53,8 @@ from deepcell.data import split_dataset
 class Track(object):  # pylint: disable=useless-object-inheritance
 
     def __init__(self, path=None, tracked_data=None,
-                 appearance_dim=32, distance_threshold=64):
+                 appearance_dim=32, distance_threshold=64,
+                 **kwargs):
         if tracked_data:
             training_data = tracked_data
         elif path:
@@ -69,6 +70,8 @@ class Track(object):  # pylint: disable=useless-object-inheritance
                 'Please make sure you are using a valid .trks file')
         self.appearance_dim = appearance_dim
         self.distance_threshold = distance_threshold
+        self.crop_mode = kwargs.get('crop_mode', 'resize')
+        self.norm = kwargs.get('norm', True)
 
         # Correct lineages and remove bad batches
         self._correct_lineages()
@@ -155,7 +158,8 @@ class Track(object):  # pylint: disable=useless-object-inheritance
 
                 frame_features = get_image_features(
                     self.X[batch, frame], self.y[batch, frame],
-                    appearance_dim=self.appearance_dim)
+                    appearance_dim=self.appearance_dim,
+                    crop_mode=self.crop_mode, norm=self.norm)
 
                 track_ids = frame_features['labels'] - 1
                 centroids[batch, frame, track_ids] = frame_features['centroids']
